pub enum UtilityCommands {
Completion {
shell: String,
install: bool,
},
}Expand description
Utility commands.
These commands provide helpful utilities for working with the HEDL CLI, including shell completion generation and help system enhancements.
Variants
Completion
Generate shell completion scripts
Generates shell completion scripts for various shells, enabling tab completion for HEDL commands, options, and file names.
Supported shells: bash, zsh, fish, powershell, elvish
Implementations